local mod = RegisterMod("Cursed Box", 1);
local item = Isaac.GetItemIdByName("Cursed Box");

local debug = false;
local game = Game();
local redeemed = true;

function mod:start()
	if game:GetFrameCount() == 0 then
		redeemed = true;
		if debug then
			Isaac.ExecuteCommand("spawn 5.100."..item);
		end
	end
end

function mod:useItem()
	local player = Isaac.GetPlayer(0);

	redeemed = false;

	--Spawns 2 ally flies and spiders
	Isaac.Spawn(EntityType.ENTITY_FAMILIAR, FamiliarVariant.BLUE_FLY, 0, player.Position, Vector(0.0, 0.0), player);
	Isaac.Spawn(EntityType.ENTITY_FAMILIAR, FamiliarVariant.BLUE_FLY, 0, player.Position, Vector(0.0, 0.0), player);
	Isaac.Spawn(EntityType.ENTITY_FAMILIAR, FamiliarVariant.BLUE_SPIDER, 0, player.Position, Vector(0.0, 0.0), player);
	Isaac.Spawn(EntityType.ENTITY_FAMILIAR, FamiliarVariant.BLUE_SPIDER, 0, player.Position, Vector(0.0, 0.0), player);

	--Removes all curses
	game:GetLevel():RemoveCurses();

	--Spawns a coin, a bomb, a key and a full red heart
	local spawn_pos = game:GetRoom():FindFreePickupSpawnPosition(player.Position, 1, true);
	Isaac.Spawn(EntityType.ENTITY_PICKUP, PickupVariant.PICKUP_COIN, 1, spawn_pos, Vector(0.0, 0.0), player);
	spawn_pos = game:GetRoom():FindFreePickupSpawnPosition(player.Position, 1, true);
	Isaac.Spawn(EntityType.ENTITY_PICKUP, PickupVariant.PICKUP_BOMB, 1, spawn_pos, Vector(0.0, 0.0), player);
	spawn_pos = game:GetRoom():FindFreePickupSpawnPosition(player.Position, 1, true);
	Isaac.Spawn(EntityType.ENTITY_PICKUP, PickupVariant.PICKUP_KEY, 1, spawn_pos, Vector(0.0, 0.0), player);
	spawn_pos = game:GetRoom():FindFreePickupSpawnPosition(player.Position, 1, true);
	Isaac.Spawn(EntityType.ENTITY_PICKUP, PickupVariant.PICKUP_HEART, 1, spawn_pos, Vector(0.0, 0.0), player);

	--Damages all enemies in the room
	local entities = Isaac.GetRoomEntities();
	for i = 1, #entities do
		if entities[i]:IsVulnerableEnemy() then
			entities[i]:TakeDamage(15.0, 0, EntityRef(player), 0);
		end
	end

	room_used_in = game:GetLevel():GetCurrentRoomIndex();
	player:RemoveCollectible(item);
	return true;
end

function mod:redeem_cursed_box()
	if not redeemed and room_used_in ~= game:GetLevel():GetCurrentRoomIndex() and game:GetRoom():IsFirstVisit() then
		local player = Isaac.GetPlayer(0)
		local entities = Isaac.GetRoomEntities();
		for i = 1, #entities do
			if entities[i].Type == EntityType.ENTITY_PICKUP and entities[i].Variant == PickupVariant.PICKUP_COLLECTIBLE then
				if entities[i].SubType ~= CollectibleType.COLLECTIBLE_NULL and not entities[i]:ToPickup():IsShopItem() then
					if entities[i].SubType ~= CollectibleType.COLLECTIBLE_POLAROID and entities[i].SubType ~= CollectibleType.COLLECTIBLE_NEGATIVE then 
						local newitem = Isaac.Spawn(EntityType.ENTITY_PICKUP, PickupVariant.PICKUP_COLLECTIBLE, item, entities[i].Position, Vector(0.0, 0.0), player);
						redeemed = true;
						newitem:ToPickup().TheresOptionsPickup = entities[i]:ToPickup().TheresOptionsPickup;
						entities[i]:Remove();
						break;
					end
				end
			end
		end
	end
end

mod:AddCallback( ModCallbacks.MC_POST_GAME_STARTED, mod.start);
mod:AddCallback( ModCallbacks.MC_USE_ITEM, mod.useItem, item);
mod:AddCallback( ModCallbacks.MC_POST_NEW_ROOM, mod.redeem_cursed_box);
mod:AddCallback( ModCallbacks.MC_POST_UPDATE, mod.redeem_cursed_box);